Index: content/browser/service_worker/service_worker_storage.h |
diff --git a/content/browser/service_worker/service_worker_storage.h b/content/browser/service_worker/service_worker_storage.h |
index d08e533094c38ffb5ca898a7e3a667c39dd14a83..fdf6fb5f9fcb1a3dc20421acedc61969b67611e8 100644 |
--- a/content/browser/service_worker/service_worker_storage.h |
+++ b/content/browser/service_worker/service_worker_storage.h |
@@ -181,11 +181,15 @@ class CONTENT_EXPORT ServiceWorkerStorage |
// Provide a storage mechanism to read/write arbitrary data associated with |
// a registration. Each registration has its own key namespace. |
// GetUserData responds OK only if all keys are found; otherwise NOT_FOUND, |
// and the callback's data will be empty. |
void GetUserData(int64_t registration_id, |
const std::vector<std::string>& keys, |
const GetUserDataCallback& callback); |
+ void GetUserDataByKeyPrefix(int64_t registration_id, |
+ const std::string& key_prefix, |
+ const GetUserDataCallback& callback); |
+ |
// Stored data is deleted when the associated registraton is deleted. |
void StoreUserData( |
int64_t registration_id, |
@@ -499,6 +503,12 @@ class CONTENT_EXPORT ServiceWorkerStorage |
int64_t registration_id, |
const std::vector<std::string>& keys, |
const GetUserDataInDBCallback& callback); |
+ static void GetUserDataByKeyPrefixInDB( |
+ ServiceWorkerDatabase* database, |
+ scoped_refptr<base::SequencedTaskRunner> original_task_runner, |
+ int64_t registration_id, |
+ const std::string& key_prefix, |
+ const GetUserDataInDBCallback& callback); |
static void GetUserDataForAllRegistrationsInDB( |
ServiceWorkerDatabase* database, |
scoped_refptr<base::SequencedTaskRunner> original_task_runner, |
@@ -181,11 +181,15 @@ class CONTENT_EXPORT ServiceWorkerStorage |
// Provide a storage mechanism to read/write arbitrary data associated with |
// a registration. Each registration has its own key namespace. |
- // GetUserData responds OK only if all keys are found; otherwise NOT_FOUND, |
- // and the callback's data will be empty. |
+ // GetUserData/GetUserDataByKeyPrefix responds OK only if all keys are found; |
+ // otherwise NOT_FOUND, and the callback's data will be empty. |
void GetUserData(int64_t registration_id, |
const std::vector<std::string>& keys, |